# TODO:
# - fix CC detection in configure, so CC=gcc won't be needed
#
# Conditional build:
%bcond_with	mpi	# MPI wrapper module
#
Summary:	An open-source memory debugger
Summary(pl.UTF-8):	Otwarty odpluskwiacz pamięci
Name:		valgrind
Version:	3.14.0
Release:	1
License:	GPL v2+
Group:		Development/Tools
Source0:	https://sourceware.org/pub/valgrind/%{name}-%{version}.tar.bz2
# Source0-md5:	74175426afa280184b62591b58c671b3
Patch0:		%{name}-native-cpuid.patch
Patch1:		%{name}-ld_linux_strlen.patch
URL:		http://valgrind.org/
BuildRequires:	autoconf >= 2.50
BuildRequires:	automake >= 1:1.10
BuildRequires:	gcc >= 5:3.0
%ifarch x32
BuildRequires:	gcc-multilib-64 >= 5:3.0
%endif
# check in configure.ac:882 AC_MSG_CHECKING([the GLIBC_VERSION version])
BuildRequires:	glibc-devel >= 6:2.2
BuildRequires:	libgomp-devel
BuildRequires:	libstdc++-devel
%{?with_mpi:BuildRequires:	mpi-devel}
Obsoletes:	valgrind-callgrind
Obsoletes:	valgrind-calltree
ExclusiveArch:	%{ix86} %{x8664} arm ppc ppc64 s390x x32
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%define		_noautostrip	.*/vgpreload.*\\.so
%define		filterout_c	-fstack-protector-strong
# ld portion broken
%undefine	with_ccache

%description
Valgrind is a GPL'd system for debugging and profiling Linux programs.
With the tools that come with Valgrind, you can automatically detect
many memory management and threading bugs, avoiding hours of
frustrating bug-hunting, making your programs more stable. You can
also perform detailed profiling to help speed up your programs.

%description -l pl.UTF-8
Valgrind jest systemem służącym do odpluskwiania i profilowania
programów na Linuksie. Używając dostarczanych z nim narzędzi można
automatycznie wykrywać wiele błędów związanych z zarządzaniem pamięcią
i wątkowaniem, dzięki czemu unika się frustrującego polowania na
błędy, a także czyni się programy bardziej stabilnymi. Możliwe jest
również dokładne profilowanie, dzięki któremu programy zaczną szybciej
pracować.

%prep
%setup -q
%patch0 -p1
%patch1 -p1

sed -i -e 's:^CFLAGS="-Wno-long-long":CFLAGS="$CFLAGS -Wno-long-long":' configure.ac

%build
%{__aclocal}
%{__autoconf}
%{__autoheader}
%{__automake}

ac_cv_path_GDB=/usr/bin/gdb \
%configure \
	CC=gcc \
	--enable-tls \
%if %{_lib} != "lib"
	--enable-only64bit \
%endif \
	--enable-lto=yes \
	LDFLAGS="" # no strip!

%{__make}

%install
rm -rf $RPM_BUILD_ROOT

%{__make} install \
	DESTDIR=$RPM_BUILD_ROOT

%{__rm} -r $RPM_BUILD_ROOT%{_datadir}/doc
cp -p docs/index.pdf docs/valgrind_manual.pdf
cp -p docs/index.ps docs/valgrind_manual.ps

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(644,root,root,755)
%doc AUTHORS NEWS README README_MISSING_SYSCALL_OR_IOCTL
%doc docs/html docs/valgrind_manual.pdf docs/valgrind_manual.ps
%attr(755,root,root) %{_bindir}/callgrind_annotate
%attr(755,root,root) %{_bindir}/callgrind_control
%attr(755,root,root) %{_bindir}/cg_annotate
%attr(755,root,root) %{_bindir}/cg_diff
%attr(755,root,root) %{_bindir}/cg_merge
%attr(755,root,root) %{_bindir}/ms_print
%attr(755,root,root) %{_bindir}/valgrind
%attr(755,root,root) %{_bindir}/valgrind-di-server
%attr(755,root,root) %{_bindir}/valgrind-listener
%attr(755,root,root) %{_bindir}/vgdb
%dir %{_libdir}/%{name}
%attr(755,root,root) %{_libdir}/%{name}/*-linux
%attr(755,root,root) %{_libdir}/%{name}/vgpreload_*-linux.so
%if %{with mpi}
# TODO: subpackage?
%attr(755,root,root) %{_libdir}/%{name}/libmpiwrap-*-linux.so
%endif
%{_libdir}/%{name}/*.xml
%{_libdir}/%{name}/default.supp
%{_libdir}/%{name}/lib*-linux.a
%{_includedir}/valgrind
%{_mandir}/man1/callgrind_annotate.1*
%{_mandir}/man1/callgrind_control.1*
%{_mandir}/man1/cg_annotate.1*
%{_mandir}/man1/cg_diff.1*
%{_mandir}/man1/cg_merge.1*
%{_mandir}/man1/ms_print.1*
%{_mandir}/man1/valgrind.1*
%{_mandir}/man1/valgrind-listener.1*
%{_mandir}/man1/vgdb.1*
%{_pkgconfigdir}/valgrind.pc
%changelog
* Fri Oct 12 2018 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/valgrind.git;a=log;h=master

* Fri Oct 12 2018 Arkadiusz Miśkiewicz <arekm@maven.pl> 644f5b9
- up to 3.14.0; enabled lto (wchich usually makes gdb unusable on binary but binary can be even 10% faster according to valgrind devs)

* Thu Aug 02 2018 Jan Palus <atler@pld-linux.org> cf76dc8
- patch from Fedora to fix "Unsupported arch_prctl option"; rel 3

* Sun Jul 15 2018 Arkadiusz Miśkiewicz <arekm@maven.pl> aa32c53
- rel 2; support ld -z separate-code generated binaries

* Sun Oct 29 2017 Arkadiusz Miśkiewicz <arekm@maven.pl> 35cbf63
- up to 3.13.0

* Mon Oct 24 2016 Arkadiusz Miśkiewicz <arekm@maven.pl> b6f066b
- up to 3.12.0

* Thu Dec 10 2015 Arkadiusz Miśkiewicz <arekm@maven.pl> 19df696
- rel 2; wrap malloc calls; no rdrand; from FC

* Mon Nov 16 2015 Jakub Bogusz <qboosh@pld-linux.org> a8c253d
- glibc 6.22 is fine now (handled by generic condition in configure)
- x32 ABI is still not supported; x32 package contains 64-bit valgrind supporting x86_64 and i386 ABIs

* Sun Nov 15 2015 Jakub Bogusz <qboosh@pld-linux.org> 4dd60bb
- updated to 3.11.0
- updated native-cpuid
- removed obsolete glibc,kernel-4.x patches

* Sun May 10 2015 Jan Rękorajski <baggins@pld-linux.org> cfde8ab
- fix build with linux 4.x
- enable x32
- rel 2

* Thu May 07 2015 Jakub Bogusz <qboosh@pld-linux.org> 9ab8af9
- added glibc patch (glibc 2.21 support)
- added mpi bcond

* Tue Mar 03 2015 Elan Ruusamäe <glen@delfi.ee> 2ea65fb
- update to 3.10.1, correct glibc version

* Tue Oct 21 2014 Jacek Konieczny <j.konieczny@eggsoft.pl> 33d3cc2
- Version: 3.10.0

* Sun Nov 03 2013 Arkadiusz Miśkiewicz <arekm@maven.pl> ef1230c
- up to 3.9.0

* Sun Oct 21 2012 Jan Rękorajski <baggins@pld-linux.org> 660a560
- rebuild to fix broken filedigests
- release 3 (by relup.sh)

* Mon Sep 24 2012 Jan Rękorajski <baggins@pld-linux.org> 0706b7f
- rebuild with fixed rpm macros
- release 2 (by relup.sh)

* Sat Sep 22 2012 Paweł Sikora <pawel.sikora@agmk.net> 9cf103c
- updated to 3.8.1.

* Thu Aug 23 2012 Paweł Sikora <pawel.sikora@agmk.net> 26efc40
- works fine, so release 1.

* Tue Aug 21 2012 Kacper Kornet <draenog@pld-linux.org> 5beaf08
- Up to 3.8.0

* Sat Jul 21 2012 Paweł Sikora <pawel.sikora@agmk.net> 7986a36
- fix build with glibc-2.16, patch signed-off-by Khem Raj.

* Sat Feb 11 2012 Arkadiusz Miśkiewicz <arekm@maven.pl> f0ea88b
- rel 4; glibc 2.15 support

